<?php

/**
* Get started notice
*/

add_action( 'wp_ajax_designer_services_dismissed_notice_handler', 'designer_services_ajax_notice_handler' );

/**
 * AJAX handler to store the state of dismissible notices.
 */
function designer_services_ajax_notice_handler() {
    if ( isset( $_POST['type'] ) ) {
        // Pick up the notice "type" - passed via jQuery (the "data-notice" attribute on the notice)
        $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
        // Store it in the options table
        update_option( 'dismissed-' . $type, TRUE );
    }
}

function designer_services_deprecated_hook_admin_notice() {
        // Check if it's been dismissed...
        if ( ! get_option('dismissed-get_started', FALSE ) ) { ?>
            <?php
            $current_screen = get_current_screen();
				if ($current_screen->id !== 'appearance_page_designer-services-guide-page') {
             $designer_services_comments_theme = wp_get_theme(); ?>
            <div class="designer-services-notice-wrapper updated notice notice-get-started-class is-dismissible" data-notice="get_started">
			<div class="designer-services-notice">
				<div class="designer-services-notice-img">
					<img src="<?php echo esc_url(get_template_directory_uri() . '/assets/images/admin-logo.png'); ?>" alt="<?php esc_attr_e('logo', 'designer-services'); ?>">
				</div>
				<div class="designer-services-notice-content">
					<div class="designer-services-notice-heading"><?php esc_html_e('Thanks for installing ','designer-services'); ?><?php echo esc_html( $designer_services_comments_theme ); ?></div>
					<p><?php printf(__('In order to fully benefit from everything our theme has to offer, please make sure you visit our <a href="%s">For Premium Options</a>.', 'designer-services'), esc_url(admin_url('themes.php?page=designer-services-guide-page'))); ?></p>
					<?php if (is_child_theme()) { ?>
						<?php $child_theme = wp_get_theme(); ?>
						<?php printf(esc_html__('You\'re using %1$s theme, It\'s a child theme of %2$s.', 'designer-services'), '<strong>' . $child_theme->Name . '</strong>', '<strong>' . esc_html__('designer_services', 'designer-services') . '</strong>'); 
						?>
						<?php
						$copy_link_args = array(
							'page' => 'designer-services',
							'action' => 'show_copy_settings',
						);
						$copy_link = add_query_arg($copy_link_args, admin_url('themes.php'));
						?>
						<?php printf('%s <a href="%s" class="go-to-setting">%s</a>', esc_html__('Now you can copy setting data from parent theme to this child theme', 'designer-services'), esc_url($copy_link), esc_html__('Copy Settings', 'designer-services')); ?>
					<?php } ?>
				</div>
			</div>
		</div>
        <?php }
	}
}

add_action( 'admin_notices', 'designer_services_deprecated_hook_admin_notice' );

add_action( 'admin_menu', 'designer_services_getting_started' );
function designer_services_getting_started() {    	    	
	add_theme_page( esc_html__('Get Started', 'designer-services'), esc_html__('Get Started', 'designer-services'), 'edit_theme_options', 'designer-services-guide-page', 'designer_services_test_guide');   
}

function designer_services_admin_enqueue_scripts() {
	wp_enqueue_style( 'designer-services-admin-style', esc_url( get_template_directory_uri() ).'/css/main.css' );
	wp_enqueue_script( 'designer-services-admin-script', get_template_directory_uri() . '/js/designer-services-admin-script.js', array( 'jquery' ), '', true );
    wp_localize_script( 'designer-services-admin-script', 'designer_services_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
}
add_action( 'admin_enqueue_scripts', 'designer_services_admin_enqueue_scripts' );

if ( ! defined( 'DESIGNER_SERVICES_DOCS_FREE' ) ) {
define('DESIGNER_SERVICES_DOCS_FREE',__('https://www.misbahwp.com/docs/designer-services-free-docs/','designer-services'));
}
if ( ! defined( 'DESIGNER_SERVICES_DOCS_PRO' ) ) {
define('DESIGNER_SERVICES_DOCS_PRO',__('https://www.misbahwp.com/docs/designer-services-pro-docs','designer-services'));
}
if ( ! defined( 'DESIGNER_SERVICES_BUY_NOW' ) ) {
define('DESIGNER_SERVICES_BUY_NOW',__('https://www.misbahwp.com/themes/designer-services-wordpress-theme/','designer-services'));
}
if ( ! defined( 'DESIGNER_SERVICES_SUPPORT_FREE' ) ) {
define('DESIGNER_SERVICES_SUPPORT_FREE',__('https://wordpress.org/support/theme/designer-services','designer-services'));
}
if ( ! defined( 'DESIGNER_SERVICES_REVIEW_FREE' ) ) {
define('DESIGNER_SERVICES_REVIEW_FREE',__('https://wordpress.org/support/theme/designer-services/reviews/#new-post','designer-services'));
}
if ( ! defined( 'DESIGNER_SERVICES_DEMO_PRO' ) ) {
define('DESIGNER_SERVICES_DEMO_PRO',__('https://www.misbahwp.com/demo/designer-services/','designer-services'));
}
if( ! defined( 'DESIGNER_SERVICES_THEME_BUNDLE' ) ) {
define('DESIGNER_SERVICES_THEME_BUNDLE',__('https://www.misbahwp.com/themes/wordpress-bundle/','designer-services'));
}

function designer_services_test_guide() { ?>
	<?php $designer_services_theme = wp_get_theme(); ?>
	
	<div class="wrap" id="main-page">
		<div id="lefty">
			<div id="admin_links">
				<a href="<?php echo esc_url( DESIGNER_SERVICES_DOCS_FREE ); ?>" target="_blank" class="blue-button-1"><?php esc_html_e( 'Documentation', 'designer-services' ) ?></a>			
				<a href="<?php echo esc_url( admin_url('customize.php') ); ?>" id="customizer" target="_blank"><?php esc_html_e( 'Customize', 'designer-services' ); ?> </a>
				<a class="blue-button-1" href="<?php echo esc_url( DESIGNER_SERVICES_SUPPORT_FREE ); ?>" target="_blank" class="btn3"><?php esc_html_e( 'Support', 'designer-services' ) ?></a>
				<a class="blue-button-2" href="<?php echo esc_url( DESIGNER_SERVICES_REVIEW_FREE ); ?>" target="_blank" class="btn4"><?php esc_html_e( 'Review', 'designer-services' ) ?></a>
			</div>
			<div id="description">
				<h3><?php esc_html_e('Welcome! Thank you for choosing ','designer-services'); ?><?php echo esc_html( $designer_services_theme ); ?>  <span><?php esc_html_e('Version: ', 'designer-services'); ?><?php echo esc_html($designer_services_theme['Version']);?></span></h3>
				<img class="img_responsive" style="width:100%;" src="<?php echo esc_url( get_template_directory_uri() ); ?>/screenshot.png">
				<div id="description-insidee">
					<?php
						$designer_services_theme = wp_get_theme();
						echo wp_kses_post( apply_filters( 'misbah_theme_description', esc_html( $designer_services_theme->get( 'Description' ) ) ) );
					?>
				</div>
			</div>
		</div>

		<div id="righty">
			<div class="postboxx donate">
				<h3 class="hndle"><?php esc_html_e( 'Upgrade to Premium', 'designer-services' ); ?></h3>
				<div class="insidee">
					<p><?php esc_html_e('Discover upgraded pro features with premium version click to upgrade.','designer-services'); ?></p>
					<div id="admin_pro_links">
						<a class="blue-button-2" href="<?php echo esc_url( DESIGNER_SERVICES_BUY_NOW ); ?>" target="_blank"><?php esc_html_e( 'Go Pro', 'designer-services' ); ?></a>
						<a class="blue-button-1" href="<?php echo esc_url( DESIGNER_SERVICES_DEMO_PRO ); ?>" target="_blank"><?php esc_html_e( 'Live Demo', 'designer-services' ) ?></a>
						<a class="blue-button-2" href="<?php echo esc_url( DESIGNER_SERVICES_DOCS_PRO ); ?>" target="_blank"><?php esc_html_e( 'Pro Docs', 'designer-services' ) ?></a>
					</div>
				</div>

				<h3 class="hndle bundle"><?php esc_html_e( 'Go For Theme Bundle', 'designer-services' ); ?></h3>
				<div class="insidee theme-bundle">
					<p class="offer"><?php esc_html_e('Get 80+ Perfect WordPress Theme In A Single Package at just $79."','designer-services'); ?></p>
					<p class="coupon"><?php esc_html_e('Exclusive Offer !! Get Our Theme Pack of 60+ WordPress Themes At 10% Off','designer-services'); ?><span class="coupon-code"><?php esc_html_e('"Themespack10"','designer-services'); ?></span></p>
					<div id="admin_pro_linkss">
						<a class="blue-button-1" href="<?php echo esc_url( DESIGNER_SERVICES_THEME_BUNDLE ); ?>" target="_blank"><?php esc_html_e( 'Theme Bundle', 'designer-services' ) ?></a>
					</div>
				</div>
				<div class="d-table">
			    <ul class="d-column">
			      <li class="feature"><?php esc_html_e('Features','designer-services'); ?></li>
			      <li class="free"><?php esc_html_e('Pro','designer-services'); ?></li>
			      <li class="plus"><?php esc_html_e('Free','designer-services'); ?></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('24hrs Priority Support','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Kirki Framework','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Posttype','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('One Click Demo Import','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Section Reordering','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Enable / Disable Option','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Multiple Sections','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Color Pallete','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Widgets','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Page Templates','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Typography','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Section Background Image / Color ','designer-services'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>		    
	  		</div>
			</div>
		</div>
	</div>

<?php } ?>
